#!/bin/sh
set -x



#####
#	script for processing IRIS Digital Data
#####

######
#	shell script to make entries for the various command files
######
#2004/05/23 09:22:05 32.53N 104.56W 5.0 4.0M A NEW MEXICO
YEAR="2006"
MO="12"
DY="26"
HR="00"
MN="58"
SEC="53"
MSEC="400"
LAT="3.30"
LON="95.98"
DEP="30."
MAG="9.0"
#ADDAFTERHERE
YEAR="2021"
MO="08"
DY="16"
HR="23"
MN="58"
SEC="56"
MSEC="000"
LAT="45.43  "
LON=" 16.27"
DEP="10.0"
MAG=" 4.7"


#####
#	No changes below here
#####
DEST=GOOD

if [ -d ${DEST} ]
then
	echo GOOD exists
else
	mkdir ${DEST}
fi


#####
#	for each SAC file
#	From the header get Network, Station, Component, Sample rate
#	Deconvolve to ground velocity with FREQLIMITS 0.002 0.004 FHL FHH
#	where the latter two are 0.25 Fnyquist and 0.5 f Nyquist
#####

#####
#	go to the raw trace directory
#####
cd Sac

#####
#    first set the coordinates so that we can apply DOCLEAN
#####
gsac << EOF
rh *SAC
ch lovrok true
ch lcalda true
ch EVLA $LAT EVLO $LON EVDP $DEP
ch OCAL $YEAR $MO $DY  $HR $MN $SEC $MSEC
wh
EOF
../DOCLEAN


for i in *.SL.*.SAC
do
KSTNM=`saclhdr -KSTNM $i`
KCMPNM=`saclhdr -KCMPNM $i`
DELTA=`saclhdr -DELTA $i`
DOY=`saclhdr -NZJDAY $i`
FHH=`echo $DELTA | awk '{print 0.50/$1}' `
FHL=`echo $DELTA | awk '{print 0.25/$1}' `
#####
#	we will not rewrite the KNETWK and KHOLE in the headers with new values
#	we will just repeat the following steps in the script
#####
KNETWK=`saclhdr -KNETWK $i`
if [ "${KNETWK}" = "-12345" ]
then
        NET=""
else
        NET="${KNETWK}"
fi
KHOLE=`saclhdr -KHOLE $i`
if [ "${KHOLE}" = "-12345" ]
then
        LOC=""
else
        LOC="${KHOLE}"
fi
DOY=`saclhdr -NZJDAY $i`
#cp RESP.${NET}.${KSTNM}.${LOC}.${KCMPNM} resp
#evalresp ${KSTNM} ${KCMPNM} ${YEAR} ${DOY} 0.001 ${FHH} 2049 -u 'vel' -f resp -use-estimated-delay
#gsac << EOF
#r $i
#ch lovrok true
#ch lcalda true
#ch EVLA $LAT EVLO $LON EVDP $DEP
#ch OCAL $YEAR $MO $DY  $HR $MN $SEC $MSEC
#wh
#rtr
##w ../${DEST}/${KSTNM}${KCMPNM}.${NET}.${LOC}.S
#transfer from eval subtype  AMP.${NET}.${KSTNM}.${LOC}.${KCMPNM} PHASE.${NET}.${KSTNM}.${LOC}.${KCMPNM} TO NONE FREQLIMITS 0.002 0.004 ${FHL} ${FHH}
#w ../${DEST}/${KSTNM}${KCMPNM}.${NET}.${LOC}.sac
#quit
#EOF
PZFILE=`ls SAC_PZs*${NET}_${KSTNM}_${KCMPNM}* | head -1`
gsac << EOF
r $i
ch lovrok true
ch lcalda true
ch EVLA $LAT EVLO $LON EVDP $DEP
ch OCAL $YEAR $MO $DY  $HR $MN $SEC $MSEC
wh
rtr
#w ../${DEST}/${KSTNM}${KCMPNM}.${NET}.${LOC}.S
#transfer from eval subtype  AMP.${NET}.${KSTNM}.${LOC}.${KCMPNM} PHASE.${NET}.${KSTNM}.${LOC}.${KCMPNM} TO NONE FREQLIMITS 0.002 0.004 ${FHL} ${FHH}
transfer from polezero subtype ${PZFILE} TO none FREQLIMITS 0.002 0.004 ${FHL} ${FHH}
div 1.0e+9
w ../${DEST}/${KSTNM}${KCMPNM}.${NET}.${LOC}.sac
quit
EOF

#####
#       deconvolve the trace
#####
done

#SCRIPT FOR IRIS DATA
