      program mlwt
c-----
c     read a set of distance ML pairs
c
c     1. set up histogram as a function of distance to define weights
c        This is done by recording the number of observations in
c        distance bins 0-ddist, ddist - 2*ddist, ..., (NBIN-1)*ddist - NBIN*ddist
c     2  weight to emphasize shorter distances
c-----
      integer NBIN
      parameter (NBIN=20)
      integer ndist(NBIN)
      real dist, mag
      real ddist
      real weight
      real distweight

c-----
c     initialize
c-----
      ddist = 50
      do i=1,NBIN
           ndist(i) = 0
      enddo
      open(1,access='sequential',form='formatted',status='scratch')
      rewind 1
      ndat = 0
 1000 continue
        read(5,*,end=1100)dist,mag
        ndat = ndat + 1
        write(1,*)dist,mag
        jbin = aint(dist/ddist) + 1
c-----
c       safety
c-----
        if (jbin.gt.NBIN)jbin = NBIN
        if (jbin.lt.0)jbin = 1
        ndist(jbin) = ndist(jbin) + 1
      go to 1000
 1100 continue
c-----
c      apply the distance binning and an ad hoc distance weight
c-----
      rewind 1
      do i=1,ndat
         read(1,*)dist,mag
         jbin = aint(dist/ddist) + 1
         if (jbin.gt.NBIN)jbin = NBIN
         if (jbin.lt.0)jbin = 1
         weight = (1.0/(1+ndist(jbin))) * distweight(dist)
         write(6,*)dist,mag,weight
      enddo
      close (1)
      end

      function distweight(dist)
c-----
c     a weighting function to emphasize short distance
c     full weighting at distances less than 100 km
c-----
      real distweight
      real distancecorner
      distancecorner = 100
      if(dist.le.distancecorner)then
           distweight = 1.0
      else
           distweight = distancecorner/dist
      endif
      return
      end
